@@ -9,8 +9,14 @@ use Data::Dumper;
 use File::chdir;
 use File::Spec;
 use File::Copy qw/copy/;
+use Perl::OSType qw/is_os_type/;
 
-use ExtUtils::LibBuilder;
+{ 
+  package Local::CBuilder;
+  use base 'ExtUtils::LibBuilder';
+  sub need_prelink { 0 }
+  sub extra_link_args_after_prelink { return }
+}
 
 my $config_file = 'config';
 my $base_config = {
@@ -41,22 +47,26 @@ sub build {
   {
     local $CWD = 'src';
 
-    my $libbuilder = ExtUtils::LibBuilder->new() or die "EU::LibBuilder object creation failed";
+    my $builder = Local::CBuilder->new();
 
     # Compile
-    my $o = $libbuilder->compile(
+    my $o = $builder->compile(
       source => 'libdontpanic.c',
       extra_compiler_flags => '-fPIC',
     );
     push @{ $config->{clean}{src} }, $o;
 
     # Link
-    my $so = "libdontpanic$libbuilder->{libext}";
-    my $soname = $^O eq 'darwin' ? '-install_name' : '-soname';
-    $libbuilder->link(
+    my $so = $builder->lib_file($o);
+    my %link_args;
+    if (is_os_type 'Unix') {
+      $link_args{extra_linker_flags} = "-Wl,-soname,$so";
+    }
+    
+    $builder->link(
       objects  => [ $o ],
-      extra_linker_flags => "-Wl,$soname,$so",
       lib_file => $so,
+      %link_args,
     );
 	
     push @{ $config->{clean}{src} }, $so;
@@ -109,17 +119,19 @@ sub _load_options {
   return $base_config unless -e $config_file;
 
   my $config = do $config_file;
+  $config ||= $base_config;
   return $config;
 }
 
 sub _store_options {
   my $opts = shift;
-  open my $fh, '>', $config_file;
+  open my $fh, '>', $config_file or die "Could not open $config_file";
   print $fh Dumper $opts;
 }
 
 sub _write_pc {
-  open my $fh, '>', 'dontpanic.pc';
+  my $pc_file = 'dontpanic.pc';
+  open my $fh, '>', $pc_file or die "Could not open $pc_file";
 
   my $prefix = $config->{prefix};
 
